[−][src]Enum unicode_types::soyombo::Soyombo
An enum to represent all characters in the Soyombo block.
Variants
LetterA\u{11a50}: '𑩐'
VowelSignI\u{11a51}: '𑩑'
VowelSignUe\u{11a52}: '𑩒'
VowelSignU\u{11a53}: '𑩓'
VowelSignE\u{11a54}: '𑩔'
VowelSignO\u{11a55}: '𑩕'
VowelSignOe\u{11a56}: '𑩖'
VowelSignAi\u{11a57}: '𑩗'
VowelSignAu\u{11a58}: '𑩘'
VowelSignVocalicR\u{11a59}: '𑩙'
VowelSignVocalicL\u{11a5a}: '𑩚'
VowelLengthMark\u{11a5b}: '𑩛'
LetterKa\u{11a5c}: '𑩜'
LetterKha\u{11a5d}: '𑩝'
LetterGa\u{11a5e}: '𑩞'
LetterGha\u{11a5f}: '𑩟'
LetterNga\u{11a60}: '𑩠'
LetterCa\u{11a61}: '𑩡'
LetterCha\u{11a62}: '𑩢'
LetterJa\u{11a63}: '𑩣'
LetterJha\u{11a64}: '𑩤'
LetterNya\u{11a65}: '𑩥'
LetterTta\u{11a66}: '𑩦'
LetterTtha\u{11a67}: '𑩧'
LetterDda\u{11a68}: '𑩨'
LetterDdha\u{11a69}: '𑩩'
LetterNna\u{11a6a}: '𑩪'
LetterTa\u{11a6b}: '𑩫'
LetterTha\u{11a6c}: '𑩬'
LetterDa\u{11a6d}: '𑩭'
LetterDha\u{11a6e}: '𑩮'
LetterNa\u{11a6f}: '𑩯'
LetterPa\u{11a70}: '𑩰'
LetterPha\u{11a71}: '𑩱'
LetterBa\u{11a72}: '𑩲'
LetterBha\u{11a73}: '𑩳'
LetterMa\u{11a74}: '𑩴'
LetterTsa\u{11a75}: '𑩵'
LetterTsha\u{11a76}: '𑩶'
LetterDza\u{11a77}: '𑩷'
LetterZha\u{11a78}: '𑩸'
LetterZa\u{11a79}: '𑩹'
LetterDashA\u{11a7a}: '𑩺'
LetterYa\u{11a7b}: '𑩻'
LetterRa\u{11a7c}: '𑩼'
LetterLa\u{11a7d}: '𑩽'
LetterVa\u{11a7e}: '𑩾'
LetterSha\u{11a7f}: '𑩿'
LetterSsa\u{11a80}: '𑪀'
LetterSa\u{11a81}: '𑪁'
LetterHa\u{11a82}: '𑪂'
LetterKssa\u{11a83}: '𑪃'
SignJihvamuliya\u{11a84}: '𑪄'
SignUpadhmaniya\u{11a85}: '𑪅'
ClusterDashInitialLetterRa\u{11a86}: '𑪆'
ClusterDashInitialLetterLa\u{11a87}: '𑪇'
ClusterDashInitialLetterSha\u{11a88}: '𑪈'
ClusterDashInitialLetterSa\u{11a89}: '𑪉'
FinalConsonantSignG\u{11a8a}: '𑪊'
FinalConsonantSignK\u{11a8b}: '𑪋'
FinalConsonantSignNg\u{11a8c}: '𑪌'
FinalConsonantSignD\u{11a8d}: '𑪍'
FinalConsonantSignN\u{11a8e}: '𑪎'
FinalConsonantSignB\u{11a8f}: '𑪏'
FinalConsonantSignM\u{11a90}: '𑪐'
FinalConsonantSignR\u{11a91}: '𑪑'
FinalConsonantSignL\u{11a92}: '𑪒'
FinalConsonantSignSh\u{11a93}: '𑪓'
FinalConsonantSignS\u{11a94}: '𑪔'
FinalConsonantSignDashA\u{11a95}: '𑪕'
SignAnusvara\u{11a96}: '𑪖'
SignVisarga\u{11a97}: '𑪗'
GeminationMark\u{11a98}: '𑪘'
Subjoiner\u{11a99}: '𑪙'
MarkTsheg\u{11a9a}: '𑪚'
MarkShad\u{11a9b}: '𑪛'
MarkDoubleShad\u{11a9c}: '𑪜'
MarkPluta\u{11a9d}: '𑪝'
HeadMarkWithMoonAndSunAndTripleFlame\u{11a9e}: '𑪞'
HeadMarkWithMoonAndSunAndFlame\u{11a9f}: '𑪟'
HeadMarkWithMoonAndSun\u{11aa0}: '𑪠'
TerminalMarkDash1\u{11aa1}: '𑪡'
TerminalMarkDash2\u{11aa2}: '𑪢'
Methods
impl Soyombo[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case